#[non_exhaustive]pub enum CompressionBackend {
Zpaq {
method: ZpaqMethodSpec,
threads: NonZeroUsize,
},
Rwkv7 {
method: MethodSpec,
coder: CoderType,
},
Rate {
rate_backend: RateBackend,
coder: CoderType,
framing: FramingMode,
},
}Expand description
Compression backend used by NCD/compression-size operations.
Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Zpaq
ZPAQ compressor with explicit method string.
Fields
method: ZpaqMethodSpecTyped ZPAQ method specification.
threads: NonZeroUsizeInternal ZPAQ compression thread count (1 => single-threaded).
Rwkv7
RWKV7 compressor configured by typed method specification.
Fields
method: MethodSpecRWKV7 method specification.
Rate
Generic rate-coded compressor wrapping an arbitrary rate backend.
Fields
rate_backend: RateBackendPredictive rate backend.
framing: FramingModeFraming mode for output payloads.
Implementations
Sourceimpl CompressionBackend
impl CompressionBackend
Sourcepub fn zpaq(method: impl Into<ZpaqMethodSpec>) -> Self
pub fn zpaq(method: impl Into<ZpaqMethodSpec>) -> Self
Construct a ZPAQ compression backend with default internal threading (threads = 1).
Sourcepub fn zpaq_with_threads(
method: impl Into<ZpaqMethodSpec>,
threads: NonZeroUsize,
) -> Self
pub fn zpaq_with_threads( method: impl Into<ZpaqMethodSpec>, threads: NonZeroUsize, ) -> Self
Construct a ZPAQ compression backend with explicit internal thread count.
Sourcepub fn try_default() -> InfotheoryResult<Self>
pub fn try_default() -> InfotheoryResult<Self>
Returns the current build’s implicit default compression backend.
Sourcepub fn validate_in(
&self,
env: &SpecEnvironment,
) -> SpecResult<ValidatedCompressionBackend>
pub fn validate_in( &self, env: &SpecEnvironment, ) -> SpecResult<ValidatedCompressionBackend>
Validate and canonicalize this backend in the provided compilation environment.
Sourcepub fn validate(&self) -> SpecResult<ValidatedCompressionBackend>
pub fn validate(&self) -> SpecResult<ValidatedCompressionBackend>
Validate and canonicalize this backend using the default environment.
Sourcepub fn compile_in(
&self,
env: &SpecEnvironment,
) -> SpecResult<CompiledCompressionBackend>
pub fn compile_in( &self, env: &SpecEnvironment, ) -> SpecResult<CompiledCompressionBackend>
Validate and compile this backend in the provided compilation environment.
Sourcepub fn compile(&self) -> SpecResult<CompiledCompressionBackend>
pub fn compile(&self) -> SpecResult<CompiledCompressionBackend>
Validate and compile this backend using the default environment.