pub fn get_default_ctx() -> InfotheoryResult<InfotheoryCtx>Expand description
Returns the current default information theory context for this thread.
pub fn get_default_ctx() -> InfotheoryResult<InfotheoryCtx>Returns the current default information theory context for this thread.