pub fn try_biased_entropy_rate_backend(
data: &[u8],
backend: &CompiledRateBackend,
) -> InfotheoryResult<f64>Expand description
Fallible biased/plugin entropy rate of data using the explicit rate backend.
pub fn try_biased_entropy_rate_backend(
data: &[u8],
backend: &CompiledRateBackend,
) -> InfotheoryResult<f64>Fallible biased/plugin entropy rate of data using the explicit rate backend.