pub fn try_entropy_rate_backend(
data: &[u8],
backend: &CompiledRateBackend,
) -> InfotheoryResult<f64>Expand description
Fallible entropy-rate estimate of data using the explicit rate backend.
pub fn try_entropy_rate_backend(
data: &[u8],
backend: &CompiledRateBackend,
) -> InfotheoryResult<f64>Fallible entropy-rate estimate of data using the explicit rate backend.