try_generate_bytes

Function try_generate_bytes 

pub fn try_generate_bytes(
    prompt: &[u8],
    bytes: usize,
) -> InfotheoryResult<Vec<u8>>
Generate a continuation from prompt using the current default context and GenerationConfig::default().

The default is deterministic frozen sampling with seed 42.