pub fn try_generate_bytes_with_config(
prompt: &[u8],
bytes: usize,
config: GenerationConfig,
) -> InfotheoryResult<Vec<u8>>Expand description
Generate a continuation from prompt using the current default context.
pub fn try_generate_bytes_with_config(
prompt: &[u8],
bytes: usize,
config: GenerationConfig,
) -> InfotheoryResult<Vec<u8>>Generate a continuation from prompt using the current default context.