pub fn try_ncd_bytes_backend(
x: &[u8],
y: &[u8],
backend: &CompiledCompressionBackend,
variant: NcdVariant,
) -> InfotheoryResult<f64>Expand description
Compute NCD for byte slices with an explicit compression backend.
pub fn try_ncd_bytes_backend(
x: &[u8],
y: &[u8],
backend: &CompiledCompressionBackend,
variant: NcdVariant,
) -> InfotheoryResult<f64>Compute NCD for byte slices with an explicit compression backend.