pub fn try_ncd_paths_backend(
x: &str,
y: &str,
backend: &CompressionBackend,
variant: NcdVariant,
) -> InfotheoryResult<f64>Expand description
Compute NCD for two files with an explicit compression backend.
pub fn try_ncd_paths_backend(
x: &str,
y: &str,
backend: &CompressionBackend,
variant: NcdVariant,
) -> InfotheoryResult<f64>Compute NCD for two files with an explicit compression backend.